<?php

namespace Drupal\Tests\drowl_trademark\Functional;

use Drupal\FunctionalJavascriptTests\WebDriverTestBase;

/**
 * This class provides methods specifically for testing something.
 *
 * @group drowl_trademark
 */
class DrowlTrademarkFunctionalJavascriptTest extends WebDriverTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'test_page_test',
    'drowl_trademark',
  ];

  /**
   * A user with authenticated permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $user;

  /**
   * A user with admin permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->config('drowl_trademark.settings')->set('drowl_trademark_replacements', 'test')->save();
    $this->createContentType(['type' => 'article']);

    $this->config('system.site')->set('page.front', '/test-page')->save();
    $this->user = $this->drupalCreateUser([]);
    $this->adminUser = $this->drupalCreateUser([]);
    $this->adminUser->addRole($this->createAdminRole('admin', 'admin'));
    $this->adminUser->save();
    $this->drupalLogin($this->adminUser);
  }

  /**
   * Tests, if the trademark symbol gets appended to a word correctly.
   */
  public function testTrademark() {
    $session = $this->assertSession();

    $this->createNode([
      'type' => 'article',
      'id' => 1,
      'title' => 'test',
      'body' => 'test',
    ]);

    $this->drupalGet('/node/1');
    $session->elementTextEquals('css', 'h1 > span', 'test<sup>®</sup>');
    $session->elementTextEquals('css', 'article > div.content > div > p', 'test<sup>®</sup>');
  }

  /**
   * Tests, if the trademark symbol does not get appended if it's inside a word.
   */
  public function testTrademarkPartOfWord() {
    $session = $this->assertSession();

    $this->createNode([
      'type' => 'article',
      'id' => 1,
      'title' => 'test',
      'body' => 'testabc',
    ]);

    $this->drupalGet('/node/1');
    $session->elementTextEquals('css', 'h1 > span', 'test<sup>®</sup>');
    $session->elementTextEquals('css', 'article > div.content > div > p', 'testabc');
  }

  /**
   * Tests, if the trademark symbol does not get appended in an excluded class.
   */
  public function testTrademarkInExcludedClass() {
    $session = $this->assertSession();

    $this->createNode([
      'type' => 'article',
      'id' => 1,
      'title' => 'test',
      'body' => '<div class="no-drowl-trademark">test</div>',
    ]);

    $this->drupalGet('/node/1');
    $session->elementTextEquals('css', 'h1 > span', 'test<sup>®</sup>');
    $session->elementTextEquals('css', 'article > div.content > div > p', 'test');
  }

}
